# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails from dynamically allocated email addresses. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://www.mailslurp.com/docs/) - [Examples](https://github.com/mailslurp/examples) repository   # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import mailslurp_client
from mailslurp_client.api.bulk_actions_controller_api import BulkActionsControllerApi  # noqa: E501
from mailslurp_client.rest import ApiException


class TestBulkActionsControllerApi(unittest.TestCase):
    """BulkActionsControllerApi unit test stubs"""

    def setUp(self):
        self.api = mailslurp_client.api.bulk_actions_controller_api.BulkActionsControllerApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_bulk_create_inboxes(self):
        """Test case for bulk_create_inboxes

        Bulk create Inboxes (email addresses)  # noqa: E501
        """
        pass

    def test_bulk_delete_inboxes(self):
        """Test case for bulk_delete_inboxes

        Bulk Delete Inboxes  # noqa: E501
        """
        pass

    def test_bulk_send_emails(self):
        """Test case for bulk_send_emails

        Bulk Send Emails  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
