# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails from dynamically allocated email addresses. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://www.mailslurp.com/docs/) - [Examples](https://github.com/mailslurp/examples) repository   # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import mailslurp_client
from mailslurp_client.api.common_actions_controller_api import CommonActionsControllerApi  # noqa: E501
from mailslurp_client.rest import ApiException


class TestCommonActionsControllerApi(unittest.TestCase):
    """CommonActionsControllerApi unit test stubs"""

    def setUp(self):
        self.api = mailslurp_client.api.common_actions_controller_api.CommonActionsControllerApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_new_email_address(self):
        """Test case for create_new_email_address

        Create new random inbox  # noqa: E501
        """
        pass

    def test_create_new_email_address1(self):
        """Test case for create_new_email_address1

        Create new random inbox  # noqa: E501
        """
        pass

    def test_empty_inbox(self):
        """Test case for empty_inbox

        Delete all emails in an inbox  # noqa: E501
        """
        pass

    def test_send_email_simple(self):
        """Test case for send_email_simple

        Send an email  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
