# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails from dynamically allocated email addresses. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://www.mailslurp.com/docs/) - [Examples](https://github.com/mailslurp/examples) repository   # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import mailslurp_client
from mailslurp_client.api.export_controller_api import ExportControllerApi  # noqa: E501
from mailslurp_client.rest import ApiException


class TestExportControllerApi(unittest.TestCase):
    """ExportControllerApi unit test stubs"""

    def setUp(self):
        self.api = mailslurp_client.api.export_controller_api.ExportControllerApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_export_entities(self):
        """Test case for export_entities

        Export inboxes link callable via browser  # noqa: E501
        """
        pass

    def test_get_export_link(self):
        """Test case for get_export_link

        Get export link  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
